# Code de conduite du Contributeur Covenant

## Notre engagement

En tant que membres, contributeurs et leaders, nous nous engageons à faire de la participation à notre communauté une expérience sans harcèlement pour tous, quel que soit l'âge, la taille, le handicap visible ou invisible, l'origine ethnique, les caractéristiques sexuelles, l'identité et l'expression de genre, le niveau d'expérience, l'éducation, le statut socio-économique, la nationalité, l'apparence personnelle, la race, la religion ou l'identité et l'orientation sexuelles.

Nous nous engageons à agir et à interagir de manière à contribuer à une communauté ouverte, accueillante, diversifiée, inclusive et saine.

## Nos normes

Exemples de comportements qui contribuent à un environnement positif pour notre  
communauté incluent :

* Faire preuve d'empathie et de bienveillance envers les autres  
* Respecter les opinions, points de vue et expériences différents  
* Donner et accepter avec grâce les retours constructifs  
* Assumer la responsabilité et présenter des excuses aux personnes affectées par nos erreurs, et tirer des leçons de l'expérience

* Se concentrer sur ce qui est le mieux, non seulement pour nous en tant qu'individus, mais pour l'ensemble de la communauté

Exemples de comportements inacceptables incluent :

* L'utilisation d'un langage ou d'imagerie sexualisés, et toute attention ou avance de nature sexuelle

* Commentaires trolls, insultants ou désobligeants, et attaques personnelles ou politiques  
* Harcèlement public ou privé  
* Publication d'informations privées d'autrui, telles qu'une adresse physique ou électronique, sans leur permission explicite

* Autres comportements qui pourraient raisonnablement être considérés comme inappropriés dans un cadre professionnel

## Responsabilités d'application

Les responsables de la communauté sont chargés de clarifier et de faire respecter nos normes de comportement acceptable et prendront des mesures correctives appropriées et équitables en réponse à tout comportement qu'ils jugent inapproprié, menaçant, offensant ou nuisible.

Les responsables de la communauté ont le droit et la responsabilité de supprimer, modifier ou rejeter les commentaires, commits, code, modifications de wiki, issues et autres contributions qui ne sont pas conformes à ce Code de conduite, et communiqueront les raisons des décisions de modération lorsque cela est approprié.

## Portée

Ce Code de conduite s'applique dans tous les espaces de la communauté, et s'applique également lorsqu'un individu représente officiellement la communauté dans des espaces publics.  
Des exemples de représentation de notre communauté incluent l'utilisation d'une adresse e-mail officielle, la publication via un compte officiel sur les réseaux sociaux, ou le fait d'agir en tant que représentant désigné lors d'un événement en ligne ou hors ligne.

## Application

Les cas de comportement abusif, harcelant ou autrement inacceptable peuvent être signalés aux responsables de la communauté chargés de l'application des règles à l'adresse aw@funstory.ai.  
Toutes les plaintes seront examinées et traitées rapidement et équitablement.  

Tous les responsables de la communauté sont tenus de respecter la confidentialité et la sécurité du signalant de tout incident.

## Directives d'application

Les responsables de la communauté suivront ces directives d'impact communautaire pour déterminer les conséquences de toute action qu'ils jugent en violation de ce code de conduite :

### 1. Correction

**Impact sur la communauté** : Utilisation d'un langage inapproprié ou d'un autre comportement jugé non professionnel ou indésirable dans la communauté.

**Conséquence** : Un avertissement écrit et privé des responsables de la communauté, clarifiant la nature de la violation et expliquant pourquoi le comportement était inapproprié. Des excuses publiques peuvent être demandées.

### 2. Avertissement

**Impact sur la communauté** : Une violation à travers un incident unique ou une série d'actions.

**Conséquence** : Un avertissement avec des conséquences pour un comportement persistant. Aucune interaction avec les personnes concernées, y compris les interactions non sollicitées avec celles chargées de faire respecter le Code de conduite, pour une période spécifiée. Cela inclut d'éviter les interactions dans les espaces communautaires ainsi que sur les canaux externes comme les réseaux sociaux. Enfreindre ces conditions peut entraîner une exclusion temporaire ou permanente.

### 3. Suspension temporaire

**Impact sur la communauté** : Une violation grave des normes de la communauté, incluant un comportement inapproprié persistant.

**Conséquence** : Une suspension temporaire de toute forme d'interaction ou de communication publique avec la communauté pour une période déterminée. Aucune interaction publique ou privée avec les personnes concernées, y compris des interactions non sollicitées avec celles chargées de faire respecter le Code de conduite, n'est autorisée pendant cette période. Le non-respect de ces conditions peut entraîner une exclusion permanente.

### 4. Bannissement permanent

**Impact sur la communauté** : Démontrer un schéma de violation des normes de la communauté, y compris un comportement inapproprié soutenu, le harcèlement d'un individu ou l'agressivité envers des classes d'individus ou leur dénigrement.

**Conséquence** : Une exclusion permanente de toute forme d'interaction publique au sein de la communauté.

## Attribution

Ce Code de conduite est adapté du [Contributor Covenant][homepage],
version 2.0, disponible à l'adresse
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.

Les directives sur l'impact communautaire s'inspirent de [l'échelle d'application du code de conduite de Mozilla](https://github.com/mozilla/diversity).

[homepage]: https://www.contributor-covenant.org

Pour les réponses aux questions fréquentes sur ce code de conduite, consultez la FAQ à l'adresse
https://www.contributor-covenant.org/faq. Des traductions sont disponibles sur
https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Une partie du contenu de cette page a été traduite par GPT et peut contenir des erreurs.</small></h6>